Welcome to weylchamber's documentation!
=======================================

.. image:: https://img.shields.io/badge/github-qucontrol/weylchamber-blue.svg
   :alt: Source code on Github
   :target: https://github.com/qucontrol/weylchamber
.. image:: https://img.shields.io/pypi/v/weylchamber.svg
   :alt: weylchamber on the Python Package Index
   :target: https://pypi.python.org/pypi/weylchamber
.. image:: https://img.shields.io/travis/qucontrol/weylchamber.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/qucontrol/weylchamber
.. image:: https://ci.appveyor.com/api/projects/status/a407jfh3gl74o1m4?svg=true
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/goerz/weylchamber
.. image:: https://img.shields.io/coveralls/github/qucontrol/weylchamber.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/qucontrol/weylchamber?branch=master
.. image:: https://readthedocs.org/projects/weylchamber/badge/?version=latest
   :alt: Documentation Status
   :target: https://weylchamber.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/License-BSD-green.svg
   :alt: BSD License
   :target: https://opensource.org/licenses/BSD-3-Clause

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   contributing
   authors
   history
   tutorial.ipynb


API
===

.. toctree::
   :maxdepth: 1

   API of the weylchamber package <API/weylchamber>

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
